summaryrefslogtreecommitdiffstats
path: root/src/phone_user.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/phone_user.h')
-rw-r--r--src/phone_user.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/phone_user.h b/src/phone_user.h
index 6e76ec8..50f86d6 100644
--- a/src/phone_user.h
+++ b/src/phone_user.h
@@ -280,11 +280,11 @@ public:
bool is_mwi_terminated(void) const;
/**
* Process an unsollicited NOTIFY for MWI.
* @param r [in] The NOTIFY request.
* @param tid [in] Transaction identifier of the NOTIFY transaction.
*/
- void handle_mwi_unsollicited(t_request *r, t_tid tid);
+ void handle_mwi_unsolicited(t_request *r, t_tid tid);
//@}
/** @name Presence */
@@ -280,11 +280,11 @@ public:
bool is_mwi_terminated(void) const;
/**
- * Process an unsollicited NOTIFY for MWI.
+ * Process an unsolicited NOTIFY for MWI.
* @param r [in] The NOTIFY request.
* @param tid [in] Transaction identifier of the NOTIFY transaction.